This patch adds a condition to avoid a memory size limitation of
swiotlb if the driver runs on IOMMU.

Tested-by: Takeshi Saito <takeshi.saito...@renesas.com>
Signed-off-by: Yoshihiro Shimoda <yoshihiro.shimoda...@renesas.com>
Reviewed-by: Simon Horman <horms+rene...@verge.net.au>
---
 drivers/mmc/host/tmio_mmc_core.c | 5 +++--
 1 file changed, 3 insertions(+), 2 deletions(-)

diff --git a/drivers/mmc/host/tmio_mmc_core.c b/drivers/mmc/host/tmio_mmc_core.c
index 130b91c..7c76ab0 100644
--- a/drivers/mmc/host/tmio_mmc_core.c
+++ b/drivers/mmc/host/tmio_mmc_core.c
@@ -1194,9 +1194,10 @@ int tmio_mmc_host_probe(struct tmio_mmc_host *_host)
         * Since swiotlb has memory size limitation, this will calculate
         * the maximum size locally (because we don't have any APIs for it now)
         * and check the current max_req_size. And then, this will update
         * the max_req_size if needed as a workaround.
         */
-       if (swiotlb_max_segment()) {
+       if (swiotlb_max_segment() && !pdev->dev.iommu_group) {
                unsigned int max_size = (1 << IO_TLB_SHIFT) * IO_TLB_SEGSIZE;
 
                if (mmc->max_req_size > max_size)
@@ -1194,9 +1194,10 @@ int tmio_mmc_host_probe(struct tmio_mmc_host *_host)
         * the maximum size locally (because we don't have any APIs for it now)
         * and check the current max_req_size. And then, this will update
-        * the max_req_size if needed as a workaround.
+        * the max_req_size if needed as a workaround. However, if the driver
+        * runs on IOMMU, this workaround isn't needed.
         */
-- 
2.7.4

Reply via email to